pub enum Error {
UploadDoesNotExit,
DigestMismatch,
Io(Error),
BackgroundTaskPanicked(JoinError),
InvalidManifest(Error),
NotATag,
}Expand description
A storage error.
Variants
UploadDoesNotExit
Attempted to submit data to an upload that does not exist.
DigestMismatch
A content hash mismatched.
Io(Error)
An IO error.
BackgroundTaskPanicked(JoinError)
A background task panicked.
InvalidManifest(Error)
Invalid image manifest submitted.
NotATag
Attempted to store a manifest under a digest instead of a tag.